@@ -7,7 +7,7 @@ class Topographic(DataSourceOutput):
     """Class to store topographic data as a xr.Dataset with some validation"""
 
     __slots__ = ()
-    _expected_dimensions = ("x", "y")
+    _expected_dimensions = ("x_osgb", "y_osgb")
     _expected_data_vars = ("data",)
 
     @classmethod
@@ -16,6 +16,6 @@ class Topographic(DataSourceOutput):
 
         v.check_nan_and_inf(data=v.data)
 
-        v.check_data_var_dim(v.data, ("example", "x_index", "y_index"))
+        v.check_data_var_dim(v.data, ("example", "x_osgb_index", "y_osgb_index"))
 
         return v
